@@ -15,17 +15,20 @@ OD_DATA_FILENAME = "OD_data.csv"
 
 
 class Experiment:
-    def __init__(self, name="NewExperiment", device_serial="auto"):
+    def __init__(self, name="NewExperiment", connect=True, device_serial="auto"):
         """
-        :param name: Experiment name, e.g. starting date. No spaces allowed
-        :param device_serial: for connecting to a specific board, input serial as string 
+        :param name: Experiment name with no spaces, e.g. starting date
+        :param device_serial: board serial number or "auto" to auto-connect
         """
         assert " " not in name
         self.directory = name
         if not os.path.exists(self.directory):
             os.mkdir(self.directory)
-        if device_serial is not None:
-            self.dev = self.connect_device(device_serial="auto")
+        if connect:
+            self.dev = self.connect_device(device_serial=device_serial)
+        else:
+            self.dev = None
+            print("Not connected to device")
         self.Valves = Valves(self)
         self.Photodiodes = Photodiodes(self)
         self.OD_measurement = ODmeasurement(self)
